#!/bin/bash
#
# Base Script Author: Pedro Pinto (pnboy~AT~pinguix.com)
#
# author           : Pedro Sousa (pedrocgsousa~AT~gmail.com)
# latest update    : 15-06-2007
# source location  : http://switch.dl.sourceforge.net/sourceforge/smbc/smbc-1.2.2.tgz
# url              : https://sourceforge.net/projects/smbc/

NAME=smbc
VERSION=1.2.2
ARCH=${ARCH:-i486}
CPU=${CPU:-i686}
BUILD=${BUILD:-48.1}
TMP=${TMP:-/tmp}
PKG=$TMP/package-$NAME
CWD=`pwd`
EXTENSION=tgz
FILENAME=$NAME-$VERSION.$EXTENSION

#
# building-computer dependent: the number of parallel 'jobs' of 'make'
#
# 'heavy' computer: 6 build-jobs at once
#
numjobs='-j6'
#
# 'light' computer: 2 build-jobs at once
#
#numjobs='-j2'

rm -rf $PKG
mkdir -p $PKG

cd $TMP
rm -rf ${FILENAME/.$EXTENSION}
  if [ -f $FILENAME ]; then
          echo "Source file already here, no need to re-download";
  elif [ -f $CWD/$FILENAME ]; then
          echo -n "Relocating source file to $TMP..."
          cp $CWD/$FILENAME $TMP/
	  echo "done"
  else
          wget -c http://switch.dl.sourceforge.net/sourceforge/$NAME/$FILENAME
  fi
  tar xf $FILENAME

cd ${FILENAME/.$EXTENSION}

# Configure:
export CFLAGS="-O2 -march=$ARCH -mtune=$CPU"
export CXXFLAGS="-O2 -march=$ARCH -mtune=$CPU"
./configure \
  --prefix=/usr \
  --sysconfdir=/etc

sed -i -e 's/CFLAGS = -O3/CFLAGS = -O2 -march=i486 -mtune=i686/g' src/Makefile

# Build and install:
make $numjobs || exit 1
make html || exit 1
make doc-r || exit 1
make install DESTDIR=$PKG || exit 1

# Strip binaries:
( cd $PKG
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# Compress the man page(s)
if [ -d $PKG/usr/man ]; then
	find $PKG/usr/man -type f -name "*.?" -exec gzip -9f {} \;
fi
if [ -d $PKG/usr/info ]; then
	find $PKG/usr/info -type f -name "*.info*" -exec gzip -9f {} \;
fi

# Add a documentation directory:
mkdir -p $PKG/usr/doc/$NAME-$VERSION

# The Makefile evidently contains the package's license...
DOCS="COPYING ChangeLog FAQ INSTALL INSTALL-Debian.pl.txt NEWS README README.build doc/manual/smbc.html doc/manual/smbc.pdf doc/manual/smbc.txt"
cd $TMP/$NAME-$VERSION
cp -a \
  $DOCS \
  $PKG/usr/doc/$NAME-$VERSION

# Removing duplicated files
mv $PKG/usr/share/smbc/sample.smbcrc $PKG/usr/doc/$NAME-$VERSION
rm -rf $PKG/usr/share/smbc

# 
# as per package rules: add the build-file itself
#
mkdir -p $PKG/usr/src/$NAME-$VERSION
cp "$CWD/build-$NAME.sh" "$PKG/usr/src/$NAME-$VERSION/build-$NAME.sh"
chmod a+x "$PKG/usr/src/$NAME-$VERSION/build-$NAME.sh"

mkdir -p $PKG/install

#    |-----handy-ruler------------------------------------------------------|
echo "$NAME: $NAME (Text Samba Network Commander)
$NAME:
$NAME: Samba Commander is a text mode SMB network commander. In SMBC, you
$NAME: can browse the local network or you can use the search function to
$NAME: find the files. You can also download/upload files and directories
$NAME: or create them both locally and remotely.
$NAME:
$NAME: 
$NAME: 
$NAME:
$NAME:" > $PKG/install/slack-desc

#
# real packaging work:
#
# Make sure ownerships and permissions are sane:
cd $PKG
chown -R root:root .
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

chmod -s -R $PKG

makepkg -l y -c n ../$NAME-$VERSION-$ARCH-$BUILD.tgz

#
# computes the md5sum signature for the package
#
cd $TMP
echo "Compute MD5..."
md5sum $NAME-$VERSION-$ARCH-$BUILD.tgz > $NAME-$VERSION-$ARCH-$BUILD.md5
echo "Finding dependencies..."
requiredbuilder -z $NAME-$VERSION-$ARCH-$BUILD.tgz > $NAME-$VERSION-$ARCH-$BUILD.dep

echo "Moving Package to: "$CWD
mv $NAME-$VERSION-$ARCH-$BUILD.* $CWD

echo "Build Complete"
